#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_content.component.illustration.interfaces import IIllustration, IIllustrationTarget
from pyams_content.component.paragraph import IBaseParagraph
from pyams_content.component.paragraph.zmi.interfaces import IParagraphContainerTable, IParagraphTitleToolbar
from pyams_form.interfaces.form import IInnerSubForm, IWidgetsPrefixViewletsManager
from pyams_skin.layer import IPyAMSLayer
from pyams_utils.interfaces import VIEW_SYSTEM_PERMISSION
from pyams_zmi.interfaces import IPropertiesEditForm
from transaction.interfaces import ITransactionManager

# import packages
from pyams_content.component.paragraph.zmi import get_json_paragraph_markers_refresh_event
from pyams_content.features.renderer.zmi.widget import RendererFieldWidget
from pyams_skin.event import get_json_form_refresh_event, get_json_widget_refresh_event
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config
from pyams_viewlet.viewlet import viewlet_config, Viewlet, EmptyViewlet
from pyams_zmi.form import InnerAdminEditForm
from z3c.form import field

from pyams_content import _


#
# Illustration properties inner edit form
#

@viewlet_config(name='illustration', context=IIllustrationTarget, layer=IPyAMSLayer, view=IParagraphContainerTable,
                manager=IParagraphTitleToolbar, permission=VIEW_SYSTEM_PERMISSION, weight=5)
@template_config(template='templates/paragraph-illustration-icon.pt', layer=IPyAMSLayer)
class ParagraphContainerIllustrationMarker(Viewlet):
    """Paragraph container illustration marker column"""

    weight = 5
    action_class = 'action illustration nowrap width-40'
    icon_class = 'fa fa-fw fa-picture-o'
    icon_hint = _("Illustration")

    marker_type = 'illustration'

    def render(self):
        illustration = IIllustration(self.context, None)
        if illustration and illustration.data:
            for value in illustration.data.values():
                if value:
                    return super(ParagraphContainerIllustrationMarker, self).render()
        return ''


@adapter_config(name='illustration', context=(IIllustrationTarget, IPyAMSLayer, IPropertiesEditForm),
                provides=IInnerSubForm)
class IllustrationPropertiesInnerEditForm(InnerAdminEditForm):
    """Illustration properties inner edit form"""

    prefix = 'illustration_form.'

    css_class = 'form-group'
    padding_class = ''
    fieldset_class = 'margin-top-10 padding-y-5'

    @property
    def legend(self):
        if IBaseParagraph.providedBy(self.context):
            return _("Illustration")
        else:
            return _("Header illustration")

    @property
    def legend_class(self):
        if IBaseParagraph.providedBy(self.context):
            return 'illustration switcher no-y-padding padding-right-10 pull-left width-auto'
        else:
            return 'illustration no-y-padding'

    fields = field.Fields(IIllustration).omit('__parent__', '__name__')
    fields['renderer'].widgetFactory = RendererFieldWidget

    hide_widgets_prefix_div = True
    weight = 10

    def getContent(self):
        return IIllustration(self.context)

    def check_mode(self):
        if self.parent_form is not None:
            self.mode = self.parent_form.mode

    def updateWidgets(self, prefix=None):
        super(IllustrationPropertiesInnerEditForm, self).updateWidgets(prefix)
        if 'description' in self.widgets:
            self.widgets['description'].widget_css_class = 'textarea'

    def get_ajax_output(self, changes):
        output = super(IllustrationPropertiesInnerEditForm, self).get_ajax_output(changes)
        updated = changes.get(IIllustration, ())
        events = output.setdefault('events', [])
        if 'data' in updated:
            # we have to commit transaction to be able to handle blobs...
            ITransactionManager(self.context).get().commit()
            events.append(get_json_form_refresh_event(self.context, self.request,
                                                      IllustrationPropertiesInnerEditForm))
            if IBaseParagraph.providedBy(self.context):
                if self.getContent().data:
                    events.append(get_json_paragraph_markers_refresh_event(self.context, self.request, self,
                                                                           ParagraphContainerIllustrationMarker))
                else:
                    events.append(get_json_paragraph_markers_refresh_event(self.context, self.request, self,
                                                                           EmptyViewlet,
                                                                           ParagraphContainerIllustrationMarker.marker_type))
        elif 'renderer' in updated:
            events.append(get_json_widget_refresh_event(self.context, self.request,
                                                        IllustrationPropertiesInnerEditForm, 'renderer'))
        return output


@viewlet_config(name='illustration-thumbnail', context=IIllustrationTarget, layer=IPyAMSLayer,
                view=IllustrationPropertiesInnerEditForm, manager=IWidgetsPrefixViewletsManager)
@template_config(template='templates/illustration-thumbnail.pt', layer=IPyAMSLayer)
class IllustrationThumbnail(Viewlet):
    """Paragraph illustration thumbnail"""

    def __new__(cls, context, request, view, manager):
        if not IBaseParagraph.providedBy(context):
            return None
        illustration = IIllustration(context, None)
        if (not illustration) or not illustration.data:
            return None
        for value in illustration.data.values():
            if value:
                return Viewlet.__new__(cls)
        return None

    def __init__(self, context, request, view, manager):
        super(IllustrationThumbnail, self).__init__(context, request, view, manager)
        self.illustration = IIllustration(context)
