#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_content.component.association.interfaces import IAssociationTarget, IAssociationItem
from pyams_sequence.interfaces import IInternalReference

# import packages
from pyams_i18n.schema import I18nTextLineField, I18nTextField
from pyams_utils.schema import MailAddressField
from zope.schema import Choice, TextLine, URI

from pyams_content import _


class IBaseLink(IAssociationItem):
    """Base link interface"""

    title = I18nTextLineField(title=_("Alternate title"),
                              description=_("Link title, as shown in front-office"),
                              required=False)

    description = I18nTextField(title=_("Description"),
                                description=_("Link description displayed by front-office template"),
                                required=False)

    def get_editor_url(self):
        """Get URL for use in HTML editor"""


class IInternalLink(IBaseLink, IInternalReference):
    """Internal link interface"""

    def get_target(self, state=None):
        """Get reference target"""


class IExternalLink(IBaseLink):
    """External link interface"""

    url = URI(title=_("Target URL"),
              description=_("URL used to access external resource"),
              required=True)

    language = Choice(title=_("Language"),
                      description=_("Language used in this remote resource"),
                      vocabulary='PyAMS base languages',
                      required=False)


class IMailtoLink(IBaseLink):
    """Mailto link interface"""

    address = MailAddressField(title=_("Target address"),
                               description=_("Target email address"),
                               required=True)

    address_name = TextLine(title=_("Address name"),
                            description=_("Address as displayed in address book"),
                            required=True)


class ILinkContainerTarget(IAssociationTarget):
    """Links container marker interface"""
