#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_content.features.header.interfaces import IHeaderTarget, IHeaderRenderer, IHeaderSettings
from pyams_content.features.renderer.interfaces import HIDDEN_RENDERER_NAME
from pyams_skin.layer import IPyAMSLayer

# import packages
from pyams_content.features.renderer.skin import BaseContentRenderer
from pyams_utils.adapter import adapter_config
from pyramid.decorator import reify

from pyams_content import _


class BaseHeaderRenderer(BaseContentRenderer):
    """Base header renderer"""

    @reify
    def settings(self):
        if self.settings_interface is None:
            return None
        settings = IHeaderSettings(self.context)
        while settings.inherit:
            settings = IHeaderSettings(settings.parent)
        return settings.settings


@adapter_config(name=HIDDEN_RENDERER_NAME, context=(IHeaderTarget, IPyAMSLayer), provides=IHeaderRenderer)
class HiddenHeaderRenderer(BaseHeaderRenderer):
    """Hidden header renderer"""

    name = HIDDEN_RENDERER_NAME
    label = _("Hidden header")
    weight = -999

    def render(self):
        return ''
