#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

# import standard library

# import interfaces
from pyams_content.portlet.content.interfaces import ISharedContentPortletSettings
from pyams_portal.interfaces import IPortalContext, IPortletRenderer
from pyams_skin.layer import IPyAMSLayer

# import packages
from pyams_content.features.renderer import IContentRenderer
from pyams_portal.portlet import PortletRenderer
from pyams_utils.adapter import adapter_config
from zope.interface import Interface

from pyams_content import _


@adapter_config(context=(IPortalContext, IPyAMSLayer, Interface, ISharedContentPortletSettings),
                provides=IPortletRenderer)
class SharedContentPortletRenderer(PortletRenderer):
    """Shared content portlet renderer"""

    label = _("Default content renderer")

    def __init__(self, context, request, view, settings):
        super(SharedContentPortletRenderer, self).__init__(context, request, view, settings)
        registry = self.request.registry
        self.renderers = [adapter for name, adapter in sorted(registry.getAdapters((self.context, self.request),
                                                                                   IContentRenderer),
                                                              key=lambda x: x[1].weight)]

    def update(self):
        super(SharedContentPortletRenderer, self).update()
        [renderer.update() for renderer in self.renderers]

    def render(self):
        result = ''
        for renderer in self.renderers:
            if renderer is not None:
                result += renderer.render()
        return result
