#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from hypatia.interfaces import ICatalog
from pyams_content.component.theme.interfaces import IThemesInfo
from pyams_content.shared.view.interfaces import IWfView, IViewSettings, IViewThemesSettings, \
    IViewQueryParamsExtension, VIEW_THEMES_SETTINGS_KEY
from zope.intid.interfaces import IIntIds

# import packages
from hypatia.query import Any
from persistent import Persistent
from pyams_catalog.query import and_
from pyams_utils.adapter import adapter_config, get_annotation_adapter, ContextAdapter
from pyams_utils.registry import get_utility
from zope.container.contained import Contained
from zope.interface import implementer
from zope.schema.fieldproperty import FieldProperty


@implementer(IViewThemesSettings)
class ViewThemesSettings(Persistent, Contained):
    """View themes settings"""

    select_context_themes = FieldProperty(IViewThemesSettings['select_context_themes'])
    themes = FieldProperty(IViewThemesSettings['themes'])

    @property
    def is_using_context(self):
        return self.select_context_themes

    def get_themes(self, context):
        themes = set()
        if self.select_context_themes:
            themes_info = IThemesInfo(context, None)
            if themes_info is not None:
                themes |= set(themes_info.themes or ())
        if self.themes:
            themes |= set(self.themes)
        return themes

    def get_themes_index(self, context):
        intids = get_utility(IIntIds)
        return [intids.register(term) for term in self.get_themes(context)]


@adapter_config(context=IWfView, provides=IViewThemesSettings)
@adapter_config(name='themes', context=IWfView, provides=IViewSettings)
def view_themes_settings_factory(view):
    """View themes settings factory"""
    return get_annotation_adapter(view, VIEW_THEMES_SETTINGS_KEY, ViewThemesSettings,
                                  name='++view:themes++')


@adapter_config(name='themes', context=IWfView, provides=IViewQueryParamsExtension)
class ViewThemesQueryParamsExtension(ContextAdapter):
    """View themes query params extension"""

    weight = 50

    def get_params(self, context):
        catalog = get_utility(ICatalog)
        settings = IViewThemesSettings(self.context)
        params = None
        # check themes
        themes = settings.get_themes_index(context)
        if themes:
            params = and_(params, Any(catalog['themes'], themes))
        return params
