#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_content.interfaces import MANAGE_CONTENT_PERMISSION
from pyams_content.shared.view.interfaces import IWfView, IViewThemesSettings, IViewsManager
from pyams_form.interfaces.form import IWidgetForm, IUncheckedEditFormButtons
from pyams_skin.interfaces import IInnerPage
from pyams_skin.layer import IPyAMSLayer
from pyams_thesaurus.interfaces.thesaurus import IThesaurusContextManager
from pyams_utils.interfaces import VIEW_SYSTEM_PERMISSION
from pyams_zmi.interfaces.menu import IPropertiesMenu
from pyams_zmi.layer import IAdminLayer
from z3c.form.interfaces import INPUT_MODE

# import packages
from pyams_form.form import ajax_config
from pyams_pagelet.pagelet import pagelet_config
from pyams_skin.viewlet.menu import MenuItem
from pyams_utils.registry import get_utility
from pyams_viewlet.viewlet import viewlet_config
from pyams_zmi.form import AdminEditForm
from z3c.form import field, button
from zope.interface import implementer, Interface

from pyams_content import _


@viewlet_config(name='themes.menu', context=IWfView, layer=IAdminLayer,
                manager=IPropertiesMenu, permission=VIEW_SYSTEM_PERMISSION, weight=350)
class ViewThemesMenu(MenuItem):
    """View themes menu"""

    label = _("Themes...")
    icon_class = 'fa-tags'
    url = '#themes.html'


@pagelet_config(name='themes.html', context=IWfView, layer=IPyAMSLayer, permission=VIEW_SYSTEM_PERMISSION)
@ajax_config(name='themes.json', context=IWfView, layer=IPyAMSLayer, permission=MANAGE_CONTENT_PERMISSION)
@implementer(IWidgetForm, IInnerPage)
class ViewThemesEditForm(AdminEditForm):
    """View themes settings edit form"""

    legend = _("View themes settings")

    fields = field.Fields(IViewThemesSettings)

    @property
    def buttons(self):
        if self.mode == INPUT_MODE:
            return button.Buttons(IUncheckedEditFormButtons)
        else:
            return button.Buttons(Interface)

    def updateWidgets(self, prefix=None):
        super(ViewThemesEditForm, self).updateWidgets(prefix)
        if 'themes' in self.widgets:
            manager = get_utility(IViewsManager)
            self.widgets['themes'].thesaurus_name = IThesaurusContextManager(manager).thesaurus_name
